summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--tests/setup.sh18
-rwxr-xr-xtests/t0010-generate-tests.sh2
-rwxr-xr-xtests/tr (renamed from tests/pwgen)0
3 files changed, 18 insertions, 2 deletions
diff --git a/tests/t0010-generate-tests.sh b/tests/t0010-generate-tests.sh
index cadb76f..09f4099 100755
--- a/tests/t0010-generate-tests.sh
+++ b/tests/t0010-generate-tests.sh
@@ -12,7 +12,7 @@ test_expect_success 'Test "generate" command' '
test_expect_success 'Test replacement of first line' '
"$PASS" insert -m cred2 <<<"$(printf "this is a big\\npassword\\nwith\\nmany\\nlines\\nin it bla bla")" &&
- PATH="$TEST_HOME:$PATH" FAKE_PWGEN_PASSWORD="This is a fake password" "$PASS" generate -i cred2 88 &&
+ PATH="$TEST_HOME:$PATH" FAKE_PWGEN_PASSWORD="This is a fake password" "$PASS" generate -i cred2 23 &&
[[ $("$PASS" show cred2) == "$(printf "This is a fake password\\npassword\\nwith\\nmany\\nlines\\nin it bla bla")" ]]
'
diff --git a/tests/pwgen b/tests/tr
index c83eec9..c83eec9 100755
--- a/tests/pwgen
+++ b/tests/tr
21Slight restructuringRené 'Necoro' Neumann4-14/+21 2021-02-21Clarify codeRené 'Necoro' Neumann1-5/+5 2021-02-21Update changelogRené 'Necoro' Neumann1-0/+2 2021-02-21#39 Ignore mails marked as deleted when looking for existing mails, as to not...René 'Necoro' Neumann1-0/+1 2021-02-21go mod tidyRené 'Necoro' Neumann1-8/+0 2021-02-18Import 'embed' packageRené 'Necoro' Neumann1-0/+1 2021-02-16Fix goreleaser setup regarding dockerRené 'Necoro' Neumann1-3/+1 2021-02-16Prepare v0.6.0v0.6.0René 'Necoro' Neumann3-3/+8 2021-02-16Fix CRLF endingRené 'Necoro' Neumann1-57/+57 2021-02-16Increment go-version to 1.16René 'Necoro' Neumann3-5/+5 2021-02-16Use go-embed for templates instead of inline strings.René 'Necoro' Neumann6-74/+79 2021-02-16Issue #46: Fix semantics of `n` resultRené 'Necoro' Neumann2-9/+15 2021-02-16Issue #46: Move and rename writer; add commentsRené 'Necoro' Neumann3-12/+21 2021-02-15Issue #46: Improvements; add testsRené 'Necoro' Neumann2-1/+48 2021-02-15Bump github.com/google/uuid from 1.1.4 to 1.2.0dependabot[bot]2-3/+3 2021-02-15Issue #46: Make the resulting email body not to include single \r or \n. This...René 'Necoro' Neumann2-2/+66 2021-01-20Bump github.com/PuerkitoBio/goquery from 1.6.0 to 1.6.1dependabot[bot]2-3/+3 2021-01-09Bump github.com/google/uuid from 1.1.2 to 1.1.4dependabot[bot]2-3/+3 2021-01-09Bump github.com/emersion/go-message from 0.14.0 to 0.14.1 (#42)dependabot[bot]2-3/+3 2020-11-28Bump github.com/emersion/go-message from 0.13.0 to 0.14.0 (#38)dependabot[bot]2-3/+9 2020-11-28Bump github.com/google/go-cmp from 0.5.2 to 0.5.4 (#37)dependabot[bot]2-3/+3 2020-11-23Fix release.ymlv0.5.2René 'Necoro' Neumann1-3/+10 2020-11-23Prepare v0.5.2René 'Necoro' Neumann3-3/+8 2020-11-20Bump github.com/gabriel-vasile/mimetype from 1.1.1 to 1.1.2dependabot[bot]2-3/+3 2020-11-04Clean dependabot.ymlRené 'Necoro' Neumann1-4/+0
diff --git a/tests/setup.sh b/tests/setup.sh
index 779f14a..5d1e794 100644
--- a/tests/setup.sh
+++ b/tests/setup.sh
@@ -7,7 +7,23 @@
# $TEST_HOME This folder
-# We must be called from tests/ !!
+# Unset config vars
+unset PASSWORD_STORE_DIR
+unset PASSWORD_STORE_KEY
+unset PASSWORD_STORE_GIT
+unset PASSWORD_STORE_GPG_OPTS
+unset PASSWORD_STORE_X_SELECTION
+unset PASSWORD_STORE_CLIP_TIME
+unset PASSWORD_STORE_UMASK
+unset PASSWORD_STORE_GENERATED_LENGTH
+unset PASSWORD_STORE_CHARACTER_SET
+unset PASSWORD_STORE_CHARACTER_SET_NO_SYMBOLS
+unset PASSWORD_STORE_ENABLE_EXTENSIONS
+unset PASSWORD_STORE_EXTENSIONS_DIR
+unset PASSWORD_STORE_SIGNING_KEY
+unset EDITOR
+
+# We must be called from tests/
TEST_HOME="$(pwd)"
. ./sharness.sh